//NPM Imports
import * as React from 'react';

//Component Imports


//Object Model Imports


//Interface(s) for this class
export interface iRowProps {
    cellWeights : Array<number>;
    className ?: string;
    children : JSX.Element[];
    borders ?: boolean;
    style ?: Array<any>;
}
export interface iRowState {
    error : string | undefined;
    // modifiedChildren: JSX.Element[];
}

export default class Row extends React.Component<iRowProps, iRowState>{

    constructor(props: iRowProps){
        super(props);
        this.state = {
            error : undefined,
        }
    }

    componentWillMount() {
        // console.log("BEGINNING OF ROW COMPONENT");
        if(this.props.cellWeights.length !== React.Children.count(this.props.children)) this.setState({error : "Cell Weights length does not match the number of child elements"});
    }

    evaluateCellWeights() {
        // console.log(this.props.children);
        let weightTotal = 0;
        this.props.cellWeights.forEach( weight => { weightTotal = weightTotal + weight; });
        
        let newModifiedChildren: Array<JSX.Element> = this.props.cellWeights.map( (cellWeight, index) => {
          let newStyle = {
              ...this.props.children[index].props.style,
              "width" : `${(cellWeight/weightTotal)*100}%`,
              "display" : "inline-block",
              // "border" : "solid 1px black"
          };

          (this.props.borders) ? newStyle = {...newStyle, "border" : "solid 1px black"} : undefined;

          return React.cloneElement(this.props.children[index], {style : newStyle});
        });

        return newModifiedChildren;
    }

    render(){
        if(this.state.error) return (<div>Error in Row Element: {this.state.error}</div>);
        
        return (
            <div className={`rowContent ${this.props.className}`} style={...this.props.style}>
                { this.evaluateCellWeights() }
            </div>
        );
    }
}